@@ -1,4 +1,4 @@
-win.strategy.default<-function(trt_con, priority, tau){
+win.strategy.default<-function(trt_con, priority, tau, np_direction){
   n_ep = length(priority)
 
   #### Obtain the indicator of the first endpoint for treatment and control
@@ -32,11 +32,20 @@ win.strategy.default<-function(trt_con, priority, tau){
     Y_l_trt = trt_con[,ind.time1.trt+l-1]; Y_l_con = trt_con[,ind.time1.con+l-1]
 
     tau_l = tau[l]
+    direction_l = np_direction[l]
+
+    if(direction_l == "larger"){
+      win.temp1 = ((delta_l_trt == 1 & delta_l_con == 1 & Y_l_trt > (Y_l_con + tau_l)) |
+                     (delta_l_trt < 1 & delta_l_con == 1 & Y_l_trt > (Y_l_con + tau_l)))
+      win.temp2 = ((delta_l_trt == 1 & delta_l_con == 1 & Y_l_con > (Y_l_trt + tau_l)) |
+                     (delta_l_trt == 1 & delta_l_con < 1 & Y_l_con > (Y_l_trt + tau_l)))
+    }else if(direction_l == "smaller"){
+      win.temp1 = ((delta_l_trt == 1 & delta_l_con == 1 & Y_l_trt < (Y_l_con - tau_l)) |
+                     (delta_l_trt < 1 & delta_l_con == 1 & Y_l_trt < (Y_l_con - tau_l)))
+      win.temp2 = ((delta_l_trt == 1 & delta_l_con == 1 & Y_l_con < (Y_l_trt - tau_l)) |
+                     (delta_l_trt == 1 & delta_l_con < 1 & Y_l_con < (Y_l_trt - tau_l)))
+    }
 
-    win.temp1 = ((delta_l_trt == 1 & delta_l_con == 1 & Y_l_trt > (Y_l_con + tau_l)) |
-                   (delta_l_trt < 1 & delta_l_con == 1 & Y_l_trt > (Y_l_con + tau_l)))
-    win.temp2 = ((delta_l_trt == 1 & delta_l_con == 1 & Y_l_con > (Y_l_trt + tau_l)) |
-                   (delta_l_trt == 1 & delta_l_con < 1 & Y_l_con > (Y_l_trt + tau_l)))
     win.status0 = cbind(win.status0, win.temp1, win.temp2)
   }
 
